@@ -1,27 +1,31 @@
 import os
 import logging
+import typing
 from typing import List
 
 from .http_client import HttpClient
 from .resources import Resources
 from .instances import Instances
+from .series import Series
+from .studies import Studies
 from .helpers import wait_until
 from .exceptions import *
+from .dicomweb_servers import DicomWebServers
 
 
 logger = logging.getLogger('api-client')
 
 
-class OrthancApiClient:
+class OrthancApiClient(HttpClient):
 
     def __init__(self, orthanc_url: str, user: str = None, pwd: str = None) -> None:
+        super().__init__(root_url=orthanc_url, user=user, pwd=pwd)
 
-        self.http_client = HttpClient(root_url=orthanc_url, user=user, pwd=pwd)
-        
-        self.patients = Resources(http_client=self.http_client, url_segment='patients')
-        self.studies = Resources(http_client=self.http_client, url_segment='studies')
-        self.series = Resources(http_client=self.http_client, url_segment='series')
-        self.instances = Instances(http_client=self.http_client)
+        self.patients = Resources(api_client=self, url_segment='patients')
+        self.studies = Studies(api_client=self)
+        self.series = Series(api_client=self)
+        self.instances = Instances(api_client=self)
+        self.dicomweb_servers = DicomWebServers(api_client=self)
 
     def wait_started(self, timeout: float = None):
         wait_until(self.is_alive, timeout)
@@ -35,7 +39,7 @@ class OrthancApiClient:
         """
         try:
             # if we get an answer to a basic request, it means the server is alive
-            self.http_client.get('system', timeout = 0.1)
+            self.get('system', timeout = 0.1)
             return True
         except Exception as e:
             return False
@@ -56,7 +60,7 @@ class OrthancApiClient:
         the instance id of the uploaded file or None when uploading a zip file
         """
         try:
-            response = self.http_client.post('/instances', data=buffer)
+            response = self.post('/instances', data=buffer)
             if isinstance(response.json(), list):
                 return [x['ID'] for x in response.json()]
             else:
@@ -118,6 +122,38 @@ class OrthancApiClient:
                 if not skip_extensions or not any([full_path.endswith(ext) for ext in skip_extensions]):
                     instances_ids.extend(self.upload_file(full_path, ignore_errors=ignore_errors))
             elif os.path.isdir(full_path):
-                instances_ids.extend(self.upload_folder(full_path, ignore_errors=ignore_errors))
+                instances_ids.extend(self.upload_folder(full_path, ignore_errors=ignore_errors, skip_extensions=skip_extensions))
         
-        return instances_ids
\ No newline at end of file
+        return instances_ids
+
+    def lookup(self, needle:str, filter:typing.List[str] = None) -> List[str]:
+        """searches the Orthanc DB for the 'needle'
+        
+        Parameters:
+        ----------
+        needle: the value to look for (may be a StudyInstanceUid, a PatientID, ...)
+        filter: the only type returned, 'None' will return all types (Study, Patient, Series, Instance)
+
+        Returns:
+        -------
+        the list of resources ids
+        """
+        response = self.post(
+            relative_url = "tools/lookup",
+            data = needle
+        )
+
+        resources = []
+        jsonResponse = response.json()
+        
+        for r in jsonResponse:
+            if r['Type'] == 'Study' and (filter is None or filter == 'Study'):
+                    resources.append(r['ID'])
+            elif r['Type'] == 'Patient' and (filter is None or filter == 'Patient'):
+                    resources.append(r['ID'])
+            elif r['Type'] == 'Series' and (filter is None or filter == 'Series'):
+                    resources.append(r['ID'])
+            elif r['Type'] == 'Instance' and (filter is None or filter == 'Instance'):
+                    resources.append(r['ID'])
+
+        return resources
\ No newline at end of file
